# Easy I.S.A 
[![Code style: black](https://img.shields.io/badge/code%20style-black-black.svg)](https://github.com/python/black)

## Introduction

This library is an implementation of the International Standard Atmoshphere equations.
The main purpose of this library is to be simple, and to be based only on in-python modules.

## TO-DO List

* [X] Create library
* [X] Create tests
* [X] Upload to [Pypi](https://packaging.python.org/tutorials/packaging-projects/)
* [ ]Create examples of use
* [ ] Maybe implement getting data as .csv or .txt?
# Installation
To install you just need to 
## References
[The International Standard Atmoshphere (ISA)](http://fisicaatmo.at.fcen.uba.ar/practicas/ISAweb.pdf)